@@ -35,20 +35,22 @@ class Freebox(IPlugin):
 	def switch(self, jsonInput):
 		rangs = [] 
 		bodies = ""
-		if jsonInput['outcome']['entities']['location']['body'] :
-			location = jsonInput['outcome']['entities']['location']['body']
-		else:
-			bodies = "pas de lieu"
-
-		if jsonInput['outcome']['entities']['on_off']['value'] :
-			on_off = jsonInput['outcome']['entities']['on_off']['value']
-		else:
-			bodies = "pas de on/off"
+		entity = jsonInput['outcome']['intent']
+		log.msg("entity :  %s" % (entity))
+		ent = entity[:5]		
+		if ent == "Fb_Ch" :
+			on_off = "ONOFF"
+			location = "VIDE"
+		else ent == "Fb_info" :
+			on_off = "ONOFF"
+		#	location = "VIDE"
+		else ent == "Fb_son" :
+		#	on_off = "ONOFF"
+			location = "VIDE"
 #
-		idex= location + "_" + on_off
+		idex= entity + "_" + location + "_" + on_off
 		log.msg("index :  %s" % (idex))	
-		
-	
+#		
 		for rs in self.configuration_plugin['param_fb']:
 			log.msg(" rs  :  %s" % (rs))
 			log.msg("ids  :  %s" % (rs['ids']))
